@@ -8,7 +8,6 @@
 #include "freebusycalendar.h"
 #include "calendarsupport_debug.h"
 
-#include <KCalendarCore/CalFormat>
 #include <KCalendarCore/FreeBusyPeriod>
 #include <KCalendarCore/MemoryCalendar>
 
@@ -21,9 +20,7 @@ using namespace CalendarSupport;
 class CalendarSupport::FreeBusyCalendarPrivate
 {
 public:
-    FreeBusyCalendarPrivate()
-    {
-    }
+    FreeBusyCalendarPrivate() = default;
 
     FreeBusyItemModel *mModel = nullptr;
     KCalendarCore::Calendar::Ptr mCalendar;
