@@ -1,25 +1,11 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FBMODEL_FREEBUSYITEMMODEL_H
-#define FBMODEL_FREEBUSYITEMMODEL_H
+#pragma once
 
 #include "calendarsupport_export.h"
 
@@ -28,9 +14,12 @@
 #include <QAbstractItemModel>
 #include <QTimer>
 
+#include <memory>
+
 class ItemPrivateData;
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 /**
  * The FreeBusyItemModel is a 2-level tree structure.
  *
@@ -43,11 +32,7 @@ class CALENDARSUPPORT_EXPORT FreeBusyItemModel : public QAbstractItemModel
 {
     Q_OBJECT
 public:
-    enum Roles {
-        AttendeeRole = Qt::UserRole,
-        FreeBusyRole,
-        FreeBusyPeriodRole
-    };
+    enum Roles { AttendeeRole = Qt::UserRole, FreeBusyRole, FreeBusyPeriodRole };
 
     explicit FreeBusyItemModel(QObject *parent = nullptr);
     ~FreeBusyItemModel() override;
@@ -93,12 +78,11 @@ protected:
 
 private:
     // Only download FB if the auto-download option is set in config
-    void autoReload();
+    CALENDARSUPPORT_NO_EXPORT void autoReload();
 
-    void setFreeBusyPeriods(const QModelIndex &parent, const KCalendarCore::FreeBusyPeriod::List &list);
-    void updateFreeBusyData(const FreeBusyItem::Ptr &);
+    CALENDARSUPPORT_NO_EXPORT void setFreeBusyPeriods(const QModelIndex &parent, const KCalendarCore::FreeBusyPeriod::List &list);
+    CALENDARSUPPORT_NO_EXPORT void updateFreeBusyData(const FreeBusyItem::Ptr &);
 
-    FreeBusyItemModelPrivate *const d;
+    std::unique_ptr<FreeBusyItemModelPrivate> const d;
 };
 }
-#endif
