@@ -3,7 +3,7 @@
   SPDX-FileCopyrightText: 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
   SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
   SPDX-FileCopyrightText: 2008 Ron Goodheart <rong.dev@gmail.com>
-  SPDX-FileCopyrightText: 2010-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010-2023 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2012-2013 Allen Winter <winter@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
@@ -435,10 +435,19 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
             drawNoteLines(p, descriptionBox, newBottom);
         }
 
-        Akonadi::Item item = mCalendar->item((*it)->uid());
-        Akonadi::Item::List relations = mCalendar->childItems(item.id());
-
         if (mShowSubitemsNotes && !isJournal) {
+            KCalendarCore::Todo::List relations;
+            for (const auto &incidence : mCalendar->incidences()) {
+                auto todo = incidence.dynamicCast<KCalendarCore::Todo>();
+                if (!todo) {
+                    continue;
+                }
+                if (todo->relatedTo() != (*it)->uid()) {
+                    continue;
+                }
+                relations.push_back(todo);
+            }
+
             if (relations.isEmpty() || (*it)->type() != KCalendarCore::Incidence::TypeTodo) {
                 int notesPosition = drawBoxWithCaption(p,
                                                        notesBox,
@@ -464,8 +473,7 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
                 QString statusString;
                 QString datesString;
                 int count = 0;
-                for (const Akonadi::Item &item : std::as_const(relations)) {
-                    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(item);
+                for (const auto &todo : std::as_const(relations)) {
                     ++count;
                     if (!todo) { // defensive, skip any zero pointers
                         continue;
@@ -729,7 +737,6 @@ void CalPrintTimetable::drawTimeTable(QPainter &p, QDate fromDate, QDate toDate,
     QDate curDate(fromDate);
     while (curDate <= toDate) {
         KCalendarCore::Event::List eventList = mCalendar->events(curDate, QTimeZone::systemTimeZone());
-        const auto holidays = holiday(curDate);
         int allDayEvents = holiday(curDate).isEmpty() ? 0 : 1;
         for (const KCalendarCore::Event::Ptr &event : std::as_const(eventList)) {
             Q_ASSERT(event);
